==> colorz-0.0.4.tar.gz: README.md <==
You're creating an app and trying out different `Colors`? A little `Colors.green`, or maybe even `Colors.teal` or `Colors.pink`?
There are so many more inspiring colors you're missing out on!

🎨 On [colornames.org](https://colornames.org/) people from all over the word come together to name colors.
This package makes the 8.000 most upvoted colors available in your Flutter app!
That's the best 0.047% of all 16.7 million RGB colors!
<!-- This package makes the 5.000 most upvoted colors available in your Flutter app!
That's the best 0.029% of all 16.7 million RGB colors! -->
<!--This package makes the 10.000 most upvoted colors available in your Flutter app!
That's the best 0.059 % of all 16.7 million RGB colors!-->
<!-- percentage: number / 256^3 -->

<!-- Join the fun and say hello to `Colorz.pickleyCactus`, `Colorz.arabicaMint` and `...`!
Make use of `Colorz.cookiemonster`, `Colorz.unoReverseCardBlue` and `Colorz.darkRavenclawBlue`!
Meet `...`, `...` and `Colorz.margesHair`! -->
<!--Highlights from top 10.000:
Join the fun and say hello to `Colorz.pickleyCactus`, `Colorz.arabicaMint` and `Colors.greenBanana`!
Make use of `Colorz.cookieMonsterCottonCandy`, `Colorz.unoReverseCardGreen` and `Colorz.darkRavenclawBlue`!
Meet `Colorz.mintyFreshToothpaste`, `Colorz.radioactiveMarijuana` and `Colorz.margesHair`!-->

⚠️ **Disclaimer:**
The color names are chosen by the community and are not censored. Therefore, color names may include words considered offensive, vulgar or obscene.

**Want to contribute?**
Visit [colornames.org](https://colornames.org/) and provide some names or vote for colors to improve this package!
If you find any issues or have ideas for improvements, don't hesitate to [create an issue in the GitHub repository](https://github.com/marcelgarus/colorz/issues/new).

**Updates of the package:**
From time to time, I'll re-generate the `Colorz` and upload a major version upgrade to pub.dev (because there may be incompatibilities with former versions).
If you want to generate the `Colorz` yourself, go into the root directory of the [<kbd>colorz</kbd>](https://github.com/marcelgarus/colorz) package and run `dart generator/generator.dart`.

==> colorz-0.0.5.tar.gz: README.md <==
You're creating an app and trying out different `Colors`? A little `Colors.green`, or maybe even `Colors.teal` or `Colors.pink`?
There are so many more inspiring colors you're missing out on!

🎨 On [colornames.org](https://colornames.org/) people from all over the word come together to name colors.
This package makes the 9.000 most upvoted colors available in your Flutter app!
That's the best 0.053% of all 16.7 million RGB colors!
<!-- This package makes the 8.000 most upvoted colors available in your Flutter app!
That's the best 0.047% of all 16.7 million RGB colors! -->
<!-- This package makes the 5.000 most upvoted colors available in your Flutter app!
That's the best 0.029% of all 16.7 million RGB colors! -->
<!--This package makes the 10.000 most upvoted colors available in your Flutter app!
That's the best 0.059 % of all 16.7 million RGB colors!-->
<!-- percentage: number / 256^3 -->

<!-- Highlights of 8.000:
Join the fun and say hello to `Colorz.pickleyCactus`, `Colorz.arabicaMint` and `...`!
Make use of `Colorz.cookiemonster`, `Colorz.unoReverseCardBlue` and `Colorz.darkRavenclawBlue`!
Meet `Colorz.driedToothpaste`, `...` and `Colorz.margesHair`! -->
<!-- Highlights of 5.000:
Join the fun and say hello to `Colorz.pickleyCactus`, `Colorz.arabicaMint` and `...`!
Make use of `Colorz.cookiemonster`, `Colorz.unoReverseCardBlue` and `Colorz.darkRavenclawBlue`!
Meet `...`, `...` and `Colorz.margesHair`! -->
<!--Highlights from top 10.000:
Join the fun and say hello to `Colorz.pickleyCactus`, `Colorz.arabicaMint` and `Colors.greenBanana`!
Make use of `Colorz.cookieMonsterCottonCandy`, `Colorz.unoReverseCardGreen` and `Colorz.darkRavenclawBlue`!
Meet `Colorz.mintyFreshToothpaste`, `Colorz.radioactiveMarijuana` and `Colorz.margesHair`!-->

⚠️ **Disclaimer:**
The color names are chosen by the community and are not censored. Therefore, color names may include words considered offensive, vulgar or obscene.

**Want to contribute?**
Visit [colornames.org](https://colornames.org/) and provide some names or vote for colors to improve this package!
If you find any issues or have ideas for improvements, don't hesitate to [create an issue in the GitHub repository](https://github.com/marcelgarus/colorz/issues/new).

**Updates of the package:**
From time to time, I'll re-generate the `Colorz` and upload a major version upgrade to pub.dev (because there may be incompatibilities with former versions).
If you want to generate the `Colorz` yourself, go into the root directory of the [<kbd>colorz</kbd>](https://github.com/marcelgarus/colorz) package and run `dart generator/generator.dart`.
